<?php
/**
 * Файл для класса описания "итога в футере грида", {@link mxl_dict_dbgridtotalfooter}.
 * @package mxl_dict
 * @author merlin <merlin@ersys.ru>
 * @copyright Copyright (c) 2009, ООО НПО Метарекс
 */
/**
 * Класс описания "итога в футере грида".
 * 
 * @package mxl_dict
 * @author merlin <merlin@ersys.ru>
 * @copyright Copyright (c) 2009, ООО НПО Метарекс, {@link http://www.metarex.ru www.metarex.ru}
 */
class mxl_dict_dbgridtotalfooter{
	/**
	 * Имя итога, должно совпадать с именем поля в гриде.
	 * @var string
	 */
	private $name;
	/**
	 * Макрос заголовка итога.
	 * Значения макроса разделяются '|';
	 * 
	 * Возможны три ситуации указания значений:
	 * 1. идентификатор значения не заполнен - общий заголовок
	 * 2. идентифиакфтор {#NVAL}= - значение определяющие текст отображения для 
	 * ситуации когда итог не имеет значение.
	 * 3. "значение=" - для указанного значения будет выведен этот текст
	 * 
	 * Пример:
	 * <code>
	 * 'Companies|{#NVAL}=No Companies|1=Company|0=Companies'
	 * </code>
	 * @var string
	 */
	private $caption;
	
	/**
	 * Текст всплывающего сообщения, которое будет отображаться
	 * при наведении на итог. 
	 * @var string
	 */
	private $hint;
	
	/**
	 * Тип итога, может принимать значения: 'sum', 'count', 'min', 'max'.
	 * @var string
	 */
	private $type;
	
	/**
	 * Проверка правильности типа итога.
	 * Если тип проходит проверку то возвращается значение true, если не 
	 * проходит то выбрасывается исключение и возвращается false. 
	 * 
	 * @param $type - проверяемый тип итога
	 * @throws Exception {@link mxl_cfg_exceptions::$dict_dbgridtotalfooter_checkType}
	 * @return boolean
	 */
	private function checkType($type){
		$type = strtolower($type);
		
  		if (($type = 'sum') || ($type = 'count') || ($type = 'min') 
  				|| ($type = 'max'))
  			return true;
  		else {
  			$errMess = mxl_cfg_exceptions::$dict_dbgridtotalfooter_checkType;
			if (strpos($errMess, '#VTINS') !== false)
				$errMess = str_replace('#VTINS', $type,	$errMess);
			throw new Exception($errMess);
  			return false;
  		} 
	}
	
	/**
	 * Конструктор класса "итоги в футере грида". Создает и инициализирует объект.
	 * Перед созданием объекта происходит проверка правильности задания типа
	 * итога, если она не проходит то выбрасывается исключение.
	 * 
	 * Особенности ввода макроса заголовка итога:<br>
	 * 1. Значения макроса разделяются '|';
	 * 2. Возможны три ситуации указания значений:
	 * 1. идентификатор значения не заполнен - общий заголовок;
	 * 2. идентифиакфтор {#NVAL}= - текст когда итог не имеет значение;
	 * 3. "значение=" - для указанного значения будет выведен этот текст.
	 
	 * Пример:
	 * <code>
	 * 'Companies|{#NVAL}=No Companies|1=Company|0=Companies'
	 * </code>

	 * @param $name - Имя итога, должно совпадать с именем поля в гриде
	 * @param $type - тип итога, может принимать значения: 'sum', 'count', 
	 * 		'min', 'max'
	 * @param $caption - Макрос заголовка итога.
	 * @param $hint - Текст всплывающего сообщения.
	 * 
	 * @throws Exception {@link mxl_cfg_exceptions::$dict_dbgridtotalfooter_checkType}
	 */
	function __construct($name, $type, $caption, $hint){
		if (!$this->checkType($type))
			exit;
			
		$this->name     = strtolower($name);
		$this->caption  = $caption;
		$this->hint     = $hint;
		$this->type     = $type;
	}
	
	/**
	 * Возвращает имя итога (совпадает с именем поля в гриде, для которого 
	 * строится итог)
	 * @return string
	 */
	public function getName(){
		return $this->name;
	}

	/**
	 * Вовращает макрос заголовка итога
	 * @return string
	 */
	public function getCaption(){
		return $this->caption;
	}
	
	/**
	 * Возвращает тип итога
	 * @return string
	 */
	public function getType(){
		return $this->type;
	}
	
	/**
	 * Возвращает текст всплывающего сообщения, которое будет отображаться
	 * при наведении на итог. 
	 * @return string
	 */
	public function getHint(){
		return $this->hint;
	}
}
?>