<?php
/**
 * Файл для класса описания атрибутов поля грида, {@link mxl_dict_fieldattribs}.
 * @package mxl_dict
 * @author merlin <merlin@ersys.ru>
 * @copyright Copyright (c) 2009, ООО НПО Метарекс
 */
/**
 * Класс описания атрибутов поля грида. 
 * @package mxl_dict
 * @author merlin <merlin@ersys.ru>
 * @copyright Copyright (c) 2009, ООО НПО Метарекс, {@link http://www.metarex.ru www.metarex.ru}
 */
class mxl_dict_fieldattribs{
	/**
	 * Поле будет доступно только для чтения.
	 */
	const readOnly  = '|RO|';
	/**
	 * Поле будет сокрыто от пользователя, но видимость можно изменить в 
	 * визуальной части.
	 */
	const hidden    = '|HD|';
	/**
	 * Отмечаются поля которые являются связанными полями из других таблиц,
	 * поля такого плана обновляются при выборе ключевого значения и не 
	 * редактируются на прямую.
	 */
	const notUpdate = '|NU|';
	/**
	 * Отмечаются поля выбор значений которых осуществляется при помощи 
	 * комбобоксов на основе перечислений.
	 */
	const enum      = '|ENUM|';
	
	/**
	 * Отмечаются поля типа int которые будут представленны в гриде в виде
	 * CheckBox. 0 - отрицательное значение, 1 - положительное
	 */
	const check     = '|CHECK|';
	
	/**
	 * Проверяет атрибуты, если есть не зарегистрированные атрибуты то 
	 * возвращает false
	 * @TODO написать процедуру
	 * @param $attribs - проверяемые атрибуты
	 * @throws {@link mxl_cfg_exceptions::$dict_fieldattribs_checkFieldAttribs}
	 * @return boolean
	 */
	public static function checkFieldAttribs($attribs){
		$checked = true;
		
		if (!$checked){
			$errMess = mxl_cfg_exceptions::$dict_fieldattribs_checkFieldAttribs;
			if (strpos($errMess, '#VTINS') !== false)
				$errMess = str_replace('#VTINS', $attribs, $errMess);
					
			throw new Exception($errMess);	
			return false;
		}
		return $checked;
		
	}
	/**
	 * Проверяет наличие атрибута $attrib в атрибутах $attribs
	 * @param $attribs - список в котором идет проверка
	 * @param $attrib - атрибут, который необходимо проверить
	 * @return boolean
	 */
	public static function checkToHaveAttrib($attribs, $attrib){
		return (strpos($attribs, $attrib) === false) ? false : true;
	}

	/**
	 * Статичная функция, которая проверяет наличие атрибута ReadOnly.
	 * @param $attribs
	 * @return boolean
	 */
	public static function isReadOnlyS($attribs){
		return mxl_dict_fieldattribs::checkToHaveAttrib($attribs, 
				mxl_dict_fieldAttribs::readOnly);
	}
	
	/**
	 * Статичная функция, которая проверяет наличие атрибута ReadOnly.
	 * @param $attribs
	 * @return boolean
	 */
	public static function isROS($attribs){
		return mxl_dict_fieldattribs::isReadOnlyS($attribs);
	}
	
	/**
	 * Статичная функция, которая проверяет наличие атрибута Hidden.
	 * @param $attribs
	 * @return boolean
	 */
	public static function isHiddenS($attribs){
		return mxl_dict_fieldattribs::checkToHaveAttrib($attribs, 
				mxl_dict_fieldAttribs::hidden);
	}
	/**
	 * Статичная функция, которая проверяет наличие атрибута Hidden.
	 * @param $attribs
	 * @return boolean
	 */
	public static function isHDS($attribs){
		return mxl_dict_fieldattribs::isHiddenS($attribs);
	}
	/**
	 * Статичная функция, которая проверяет наличие атрибута NoUpdate.
	 * @param $attribs
	 * @return boolean
	 */
	public static function isNotUpdateS($attribs){
		return mxl_dict_fieldattribs::checkToHaveAttrib($attribs, 
				mxl_dict_fieldAttribs::notUpdate);
	}
	/**
	 * Статичная функция, которая проверяет наличие атрибута NoUpdate.
	 * @param $attribs
	 * @return boolean
	 */
	public static function isNUS($attribs){
		return mxl_dict_fieldattribs::isNotUpdateS($attribs);
	}

	/**
	 * Статичная функция, которая проверяет наличие атрибута Enum.
	 * @param $attribs
	 * @return boolean
	 */
	public static function isEnumS($attribs){
		return mxl_dict_fieldattribs::checkToHaveAttrib($attribs, 
				mxl_dict_fieldAttribs::enum);
	}
	
	/**
	 * Статичная функция, которая проверяет наличие атрибута Check.
	 * @param $attribs
	 * @return boolean
	 */
	public static function isCheckS($attribs){
		return mxl_dict_fieldattribs::checkToHaveAttrib($attribs, 
				mxl_dict_fieldAttribs::check);
	}
	/**
	 * Атрибуты
	 * @var string
	 */
	private $attribs;
	
	/**
	 * Конструктор класса, перед созданием проверяет атрибуты на наличие 
	 * не зарегистрированных, если находит то выбрасывает исключение
	 * @param $attribs
	 * @throws {@link mxl_cfg_exceptions::$dict_fieldattribs_checkFieldAttribs}
	 * @return mxl_dict_fieldattribs
	 */
	function __construct($attribs){
		if (mxl_dict_fieldattribs::checkFieldAttribs($attribs)){
			$this->attribs = $attribs;
		}
	}
	
	/**
	 * Проверяет на наличие атрибута ReadOnly в экземпляре класса
	 * @return boolean
	 */
	public function isReadOnly(){
		return mxl_dict_fieldattribs::isReadOnlyS($this->attribs);
	}
	/**
	 * Проверяет на наличие атрибута ReadOnly в экземпляре класса
	 * @return boolean
	 */
	public function isRO(){
		return $this->isReadOnly();
	}
	
	/**
	 * Проверяет на наличие атрибута Hidden в экземпляре класса
	 * @return boolean
	 */
	public function isHidden(){
		return mxl_dict_fieldattribs::isHiddenS($this->attribs);
	}
	/**
	 * Проверяет на наличие атрибута Hidden в экземпляре класса
	 * @return boolean
	 */
	public function isHD(){
		return $this->isHidden();
	}
	
	/**
	 * Проверяет на наличие атрибута NotUpdate в экземпляре класса
	 * @return boolean
	 */
	public function isNotUpdate(){
		return mxl_dict_fieldattribs::isNotUpdateS($this->attribs);
	}
	/**
	 * Проверяет на наличие атрибута NotUpdate в экземпляре класса
	 * @return boolean
	 */
	public function isNU(){
		return $this->isNotUpdate();
	}
	
	/**
	 * Проверяет на наличие атрибута Enum в экземпляре класса
	 * @return boolean
	 */
	public function IsEnum() {
		return mxl_dict_fieldattribs::isEnumS($this->attribs);
	}

	/**
	 * Проверяет на наличие атрибута Check в экземпляре класса
	 * @return boolean
	 */
	public function IsCheck() {
		return mxl_dict_fieldattribs::isCheckS($this->attribs);
	}
	/**
	 * Добавляет атрибуты к текущим с предварительной проверкой
	 * @param string $attribs - добавляемые атрибуты
	 */
	public function addAtribs($attribs){
		if (mxl_dict_fieldattribs::isCheckS($attribs)&&
				!mxl_dict_fieldattribs::isCheckS($this->attribs)){
			$this->attribs .= mxl_dict_fieldattribs::check;
		}
		if (mxl_dict_fieldattribs::isEnumS($attribs)&&
				!mxl_dict_fieldattribs::isEnumS($this->attribs)){
			$this->attribs .= mxl_dict_fieldattribs::enum;
		}
		if (mxl_dict_fieldattribs::isHDS($attribs)&&
				!mxl_dict_fieldattribs::isHDS($this->attribs)){
			$this->attribs .= mxl_dict_fieldattribs::hidden;
		}
		if (mxl_dict_fieldattribs::isNUS($attribs)&&
				!mxl_dict_fieldattribs::isNUS($this->attribs)){
			$this->attribs .= mxl_dict_fieldattribs::notUpdate;
		}
		if (mxl_dict_fieldattribs::isROS($attribs)&&
				!mxl_dict_fieldattribs::isROS($this->attribs)){
			$this->attribs .= mxl_dict_fieldattribs::readOnly;
		}
	}
}
?>