<?php	
/**
 * Файл для описания класса экспорта данных грида, {@link mxl_utils_dbgridexport}.
 * @package mxl_utils
 * @author joska <joska@ersys.ru>
 * @copyright Copyright (c) 2009, ООО НПО Метарекс
 */
/**
 * Класс экспорта данных грида.
 * @package mxl_utils
 * @author joska <joska@ersys.ru>
 * @copyright Copyright (c) 2009, ООО НПО Метарекс, {@link http://www.metarex.ru www.metarex.ru}
 */
class mxl_utils_dbgridexport {

	/**
	 * Константа формата даты для вывода поля с типом edatetime
	 * @var string
	 */
	const   DATEFORMAT   = '%Y-%m-%d';
	
	/**
	 * Константа формата времени для вывода поля с типом edatetime
	 * @var string
	 */
	const   TIMEFORMAT   = '%H:%M';
	
	/**
	 * Константа новой строки
	 * @var string
	 */
	const   NL           = '\n';
	
	/**
	 * Переменная для хранения значения разделителя значений для csv
	 * файла. Значение разделителя берется из параметров локали.
	 * @var string
	 */
	private $delim       = ';';
	
	/**
	 * Формат представления экспортированных данных
	 * @var string
	 */
	private $format      = '';
	
	/**
	 * Заголовок Content-type для ответа 
	 * @var string
	 */
	private $contenttype = ''; 

	/**
	 * Имя возвращаемого файла (с расширением)
	 * @var string
	 */
	private $filename    = '';
	
	/**
	 * Метаданные грида для выгрузки
	 * @var mxl_dict_dbgrid
	 */
	private $dbgrid = NULL;
	
	/**
	 * Конструктор класса. Создает объект класса и инициализирует начальными 
	 * значениями.
	 * 
	 * @param $dbgrid - метаданные грида для выгрузки
	 * @param $format - формат представления экспортированных данных
	 * @param $filename - имя возвращаемого файла (с расширением)
	 * @return mxl_utils_dbgridexport
	 */
	function __construct(mxl_dict_dbgrid $dbgrid, $format, $filename = '') {

		$this->dbgrid  = $dbgrid;
		$this->format  = $format;
		$this->delim   = mxl_cfg_base::$exportcvs_delimeter;
		switch($format){
			case 'csv':
				$contenttype = 'Content-type: text/csv';
				if ($filename != '') $this->filename = $filename;
				else $this->filename = 'exp_'.date("YmdHis").'.csv';		
				break;
			default:
				$contenttype = 'Content-type: text/txt'; 
				if ($filename != '') $this->filename = $filename;
				else $this->filename = 'exp_'.date("YmdHis").'.txt';
				break;
		}
	}
	
	/**
	 * Метод возвращает файл с эспортированными данными.
	 * Вид ответа задаётся с помощью стандартной функции header,  
	 * вывод осуществляется при помощи функции echo.
	 * Если во время сбора или формирования данных произошла ошибка,
	 * она будет выведена в файл.
	 */
	public function getFile() {
		header($this->contenttype);
		header('Content-Disposition: attachment; filename="'.$this->filename.'"');
		
		try {	
			switch($this->format){
				case 'csv':
					echo $this->getCSV();
					break;
				default:
		        	echo '{failure:true}';
		        	break;
			}
		        
		} catch (Exception $e){
			echo '{failure:true, error:'.json_encode(mxl_utils_exceptions::toHtml($e)).'}';
		}
	}

	/**
	 * Метод собирает данные грида в csv формат и возвращает получившуюся 
	 * строку. 
	 * @return string
	 */
	private function getCSV() {
		$MXL_LDBS = new mxl_core_logicbases();
		$MXL_DB = $MXL_LDBS->getLogicBaseInst($this->dbgrid->getLogicBaseName());
			
		$query = $this->dbgrid->getSelectSQL();
		
		$result = $MXL_DB->sql_query($query);
		
		$text = '';
		$str  = '';
		foreach ($this->dbgrid->getListFields() as $FI){
			$str .= $str == '' ? '' : $this->delim;
			//if (!$FI->getAttribs()->isHD()) {
				$caption = $FI->getCaption();
				$str .= html_entity_decode(strip_tags($caption), ENT_COMPAT);
			//}
		}
		$text .= $str.mxl_utils_dbgridexport::NL;
		while ($r = $MXL_DB->sql_fetchrow($result)) {
			$str = '';
			foreach ($this->dbgrid->getListFields() as $FI){
				$value = ''; 
				//if (!$FI->getAttribs()->isHD()) {
        			$str .= $str == '' ? '' : $this->delim;
					$dt = strtolower($FI->getDataType());
					if ($dt == 'edatetime') {
						$value = strftime(mxl_utils_dbgridexport::DATEFORMAT, $r[$FI->getName()])
                                .' '.strftime(mxl_utils_dbgridexport::TIMEFORMAT, $r[$FI->getName()]);
					} else if ($dt == 'date') {
						$value = strftime(mxl_utils_dbgridexport::DATEFORMAT, $r[$FI->getName()]);
					} else {
						$value = $r[$FI->getName()];
					}			
					
					$value = html_entity_decode(strip_tags($value), ENT_COMPAT);
					if (($dt == 'edatetime')||($dt == 'date')||($dt == 'string')) {
						$value = '"'.$value.'"';
					}
					$str .= $value;	
				//}
			}
			$text .= $str.mxl_utils_dbgridexport::NL;
		}
		$MXL_DB->sql_freeresult($result);
		
		$text  = str_replace('\\r', "\015", $text);
		$text  = str_replace('\\n', "\012", $text);
		$text  = str_replace('\\t', "\011", $text);
		$text  = str_replace('ID',  '"ID"', $text); // Особенностm работы Microsoft Office с форматом CSV
			
		return $text;
	}
}


?>