<?php
/**
 * Файл для описания класса хранилища визуальных компонентов, 
 * {@link mxl_widget_widgets}.
 * @package mxl_widget
 * @author merlin <merlin@ersys.ru>
 * @copyright Copyright (c) 2009, ООО НПО Метарекс
 */
/**
 * Класс описания хранилища визуальных компонентов.
 * 
 * Пример использования:
 * <code>
 * $WGS = new mxl_widget_widgets();
 * $WGS->addWidget(new mxl_widget_combobox('countries25', 'countriesWhereLess50'));
 * $WGS->addWidget(new mxl_widget_combobox('companies23', 'companies', 14));
 * $WGS->addWidget(new mxl_widget_combobox('combotest27', 'testComboboxEnumYesNo', 1));
 * $WGS->addWidget(new mxl_widget_comboboxseach('combotest26', 'combotest'));
 * $WGS->addWidget(new mxl_widget_dbgrid(  'gbg27',       'loc1'));
 * $WGS->addWidget(new mxl_widget_datetime('start', mktime( 0, 0,0,date('m'),date('d'),date('Y'))));
 * $WGS->addWidget(new mxl_widget_datetime('end'));
 * $WGS->wgDateTimeSetVal('end', mktime(23,59,0,date('m'),date('d'),date('Y')));
 * $WGS->wgDateTimeAddRange('start', 'end');
 * $fileName = realpath(dirname(__FILE__).'\js_cash').'\c1.js';
 * $WGS->WriteJScript($fileName);
 * </code>
 * 
 * @package mxl_widget
 * @author merlin <merlin@ersys.ru>
 * @copyright Copyright (c) 2009, ООО НПО Метарекс, {@link http://www.metarex.ru www.metarex.ru}
 */
class mxl_widget_widgets {
	/**
	 * Массив для хранения визульных компонентов
	 * @var array
	 */
	private $listWidget;
	
	/**
	 * Переменная для хранения смещения времени относительно центрального 
	 * сервера в часах.
	 * @var float
	 */
	private $timeShift;
		
	/**
	 * Конструктор
	 * @return mxl_widget_widgets
	 */
	function __construct(){
		$this->timeShift  = 0;
		$this->listWidget = array();
	}
	
	/**
	 * Деструктор
	 */
	function __destruct(){
		unset($this->listWidget);
	}
	
	/**
	 * функция проверяет наличие виджета с именем $widgetName, и 
	 * выбрасывает исключение если таковое имеется. 
	 * Актуальна при добавлении нового виджета.
	 * 
	 * @param string $widgetName - имя проверяемого перечисления
	 * @throws Exception {@link mxl_cfg_exceptions::$widget_widgets_checkDontHave}
	 * @return boolean
	 */
	private function checkDontHave($widgetName){
		if (array_key_exists($widgetName, $this->listWidget)){
			$errMess = mxl_cfg_exceptions::$widget_widgets_checkDontHave;
			if (strpos($errMess, '#VTINS') !== false)
				$errMess = str_replace('#VTINS', $widgetName, $errMess);
					
			throw new Exception($errMess);	
			return false;
		} else
			return true; 
	}
	/**
	 * Метод добавляет виждет в хранилище. Перед добавлением производится 
	 * проверка на наличие в хранилище виджета с таким именем, если уже есть
	 * такое имя то выбрасывается исключение.
	 * @param mxl_widget_widget $widget
	 * @throws Exception {@link mxl_cfg_exceptions::$widget_widgets_checkDontHave}
	 * @return unknown_type
	 */
	public function addWidget(mxl_widget_widget $widget){
		$widgetName = $widget->getName();
		if ($this->checkDontHave($widgetName)){
			$widget->setTimeShift($this->getTimeShift());
			
			$this->listWidget[$widgetName] = $widget;
		}
	}
	
	/**
	 * Метод формирует код JavaScript для компонентов находящихся в хранилище.
	 * Принцип формирования JS кода описан в 
	 * {@link mxl_widget_widget::getJSCode()}.
	 * @param boolean $append_SID - использовать ли параметр _SID в baseParams
	 * @return string
	 */
	public function MakeJS($append_SID = true){
		$MDS = mxl_core_metadatas::instance();
		
		$declatePartCommon =
                'var mxl_wgs_time_shift = '.
                ($this->getTimeShift() ? $this->getTimeShift() : '0').';'.NL.
                'var mxl_wgs_server_time_zone = '.
                "'".mxl_cfg_base::$server_time_zone."'".';'.NL;
		
		$declarePartPers   = '';
		$runPartFirst      = '';
		$runPartLast       = '';
		$funcsAfterInit    = '';
		foreach ($this->listWidget as $widget){
			$declPP = '';
			$runPF  = '';
			$runPL  = '';
			
			$MDS->setCurrParams($widget->getParams());
			$widget->getJSCode($declatePartCommon, $declPP, $runPF, $runPL,
					$funcsAfterInit, $append_SID);
			
			$declarePartPers .= $declPP;
			$runPartFirst    .= $runPF;
			$runPartLast     .= $runPL;
		}

        $z = 'function Get_SID() {'.NL
	  	   . '  var pageParameters = Ext.urlDecode(window.location.search.substring(1));'.NL
           . '  return pageParameters["sid"];'.NL 
           . '}'.NL; 

        $z1  = mxl_widget_extjs::getInitHtmpPageOnBeforeUnload();
        $z1 .= 'Ext.QuickTips.init();'.NL; 
		
        $declatePartCommon = mxl_widget_extjs::getFuncText_mxl_showErrorByResponseText().
        		NL.$declatePartCommon;
        $declarePartPers  .= NL.mxl_widget_extjs::getFuncText_mxl_onbeforeunload($this);

        //$result  = mxl_widget_extjs::get_class_ClearableComboBox();  
        $result = NL.$declatePartCommon.NL.$declarePartPers.NL
				. 'function startAutoGenScript(){'.NL.$runPartFirst.NL
				. $runPartLast.NL.$z1.NL
                . '  Ext.data.DataProxy.addListener(\'exception\', function(proxy, type, action, options, response, arg) {'.NL
                . '    if (type == \'response\'){'.NL
                . '      mxl_showErrorByResponseText(response.responseText, ""); '.NL
                . '    } else {'
                . '      Ext.Msg.show({ '.NL
                . '        title: \'Ошибка\','.NL
                . '        msg: print_r(response),'.NL
                . '        icon: Ext.MessageBox.ERROR,'.NL
                . '        buttons: Ext.Msg.OK'.NL
                . '      });'.NL
                . '    }'.NL
                . '  });'.NL
                .'}'.NL
				.$funcsAfterInit.NL.$z;
				
		return $result;	
	}
	/**
	 * Процедура формирует JS код и пишет его в файл с именем $fileName.
	 * @param string $fileName - имя файла, куда следует поместить JS код
	 * @param boolean $generate - должна ли отработать функция
	 */
	public function WriteJScript($fileName, $generate = true){
        if ($generate){
        	$fh = fopen($fileName, 'wb') or die('can\'t create file '.$fileName);
			fwrite($fh, $this->MakeJS());
			fclose($fh);  
        }
	}
	
	/**
	 * Функция костыль, опирается на глобальную переменную $template, 
	 * в которую подсовывает сформированный JS код для библиотеки ExtJS
	 * @param boolean $append_SID - использовать ли параметр _SID в baseParams
	 */
	public function PutScriptToHeader($append_SID = true){
		$x  = '<script language="JavaScript" type="text/javascript">' .NL;
		$x .= $this->MakeJS($append_SID);
		$x .= '</script>' .NL;

		if (defined('SMARTY') && SMARTY){
			global $smarty;
			$smarty->assign('EXTJS_AUTOGENSCRIPT_LINKS', $x);
		} else {
			global $template;
			$template->assign_var('EXTJS_AUTOGENSCRIPT_LINKS', $x);
		}
	}  
	
	/**
	 * Проверка является ли виджет объектом класса {@link mxl_widget_datetime},
	 * если не является то выбрасывается исключение.
	 * @param mxl_widget_widget $widget - проверяемый виджет
	 * @throws Exception mxl_cfg_exceptions::$widget_widgets_checkWidgetIsDateTime
	 * @return unknown_type
	 */
	private function checkWidgetIsDateTime(mxl_widget_widget $widget){
		if (!($widget instanceof mxl_widget_datetime)){
			$errMess = mxl_cfg_exceptions::$widget_widgets_checkWidgetIsDateTime;
			if (strpos($errMess, '#VTINS') !== false)
				$errMess = str_replace('#VTINS', $widget->getName(), $errMess);
					
			throw new Exception($errMess);	
		}else
			return true;
	}
	
	/**
	 * Метод связывает компоненты даты-времени как начальный и конечный.
	 * @param $startName - начальный компонент дата-время
	 * @param $endName - конечный компонент дата-время
	 */
	public function wgDateTimeAddRange($startName, $endName) {
		$widgetStart = $this->listWidget[$startName]; 
		$widgetEnd   = $this->listWidget[$endName];
		
		if (	   $this->checkWidgetIsDateTime($widgetStart) 
				&& $this->checkWidgetIsDateTime($widgetEnd)){

			$widgetStart->setEndRangeName($endName);
			$widgetEnd->setStartRangeName($startName);
		}
	}
	
	/**
	 * Устанавливает начальное значение для компонента дата время.
	 * @param $wgName - имя компонента дата-время
	 * @param $intDateTime - начальное значение
	 */
	public function wgDateTimeSetVal($wgName, $intDateTime){
		$widget = $this->listWidget[$wgName]; 
		if ($this->checkWidgetIsDateTime($widget))
			$widget->setDateTime($intDateTime);
	}
	
	/**
	 * Возвращает массив виджетов
	 * @return array
	 */
	public function getListWidget(){
		return $this->listWidget;
	}
	
	/**
	 * Устанавливает смещение времени относительно времени центрального сервера.
	 * @param float $timeShift - смещение времени в часах
	 */
	public function setTimeShift($timeShift){
		$this->timeShift = $timeShift;
	}
	
	/**
	 * Возвращает смещение времени относительно времени центрального сервера в 
	 * часах.
	 * @return float
	 */
	public function getTimeShift(){
		return $this->timeShift;
	}
}
?>